@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Math.py
-Version : 1.1.0
+Version : 1.1.1
 Author  : Stefano Covino
-Date    : 11/08/2010
+Date    : 13/07/2010
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -14,7 +14,7 @@ Remarks : Output coordinates in degrees.
 
 History : (06/08/2010) First version.
         : (11/08/2010) Check on not physical input.
-
+        : (13/07/2016) Better check on input.
 """
 
 
@@ -28,11 +28,20 @@ class AstroCoordInput:
         #   than degrees.
         # RA
         if str(ra).find(':') > 0:
-            ira = ephem.hours(ra)
+            try:
+                ira = ephem.hours(ra)
+            except ValueError:
+                ira = -99.
         else:
-            ira = ephem.degrees(str(ra))
+            try:
+                ira = ephem.degrees(str(ra))
+            except ValueError:
+                ira = -99.
         # DEC
-        idec = ephem.degrees(str(dec))
+        try:
+            idec = ephem.degrees(str(dec))
+        except ValueError:
+            idec = -99.
         icoordset = ephem.Equatorial(ira,idec,epoch=inp_equinox)
         ocoordset = ephem.Equatorial(icoordset,epoch=out_equinox)
         self.RA = math.degrees(ocoordset.ra)
